<h1 align="center">checkeml</h1>
<p align="center">It is a useful library for developers as it checks the email if it is on social networking sites or not</p>

![](https://img.shields.io/badge/SidraELEzz-orange?style=for-the-badge&logo=python.svg) 
<p align="center">
<a href="#"><img title="Made in UAE" src="https://img.shields.io/badge/MADE%20IN-UAE-red.svg?style=for-the-badge&logo=github"></a>

</p>
<p align="center">
<img alt="SidraELEzz' Github Stats" src="https://github-readme-stats.vercel.app/api?username=SidraELEzz&show_icons=true&include_all_commits=true&hide_border=true" />

</p>
<p align="center">
<a href="#"><img title="telegram Num" src="https://img.shields.io/badge/telegram%20Num-SidtaTools-red.svg?style=for-the-badge&logo=telegram"></a>
</p>
<p align="center">
<a href="https://github.com/SidraELEzz/followers"><img title="Followers" src="https://img.shields.io/github/followers/SidraELEzz?color=blue&style=flat-square"></a>
</p>

## Installation :
```
pip install checkeml
```
## ***TSM are available***

⌯ instagram 

⌯ facebook 

⌯ twitter

### checker email facebook 

``` python
from checkeml import checkeml

email = "<your email>"

Logan = checkeml.facebook(str(email))

if Logan ==True:
	print ("Email facebook is available")
	
elif Logan ==False:
	print("Email facebook is not available")

	
	
```
### checker email twitter 

``` python
from checkeml import checkeml

email = "<your email>"

Logan = checkeml.twitter(str(email))

if Logan ==True:
	print ("Email twitter is available")
	
elif Logan ==False:
	print("Email twitter is not available")

	
	
```


## Follow us on social media

[![Github](https://img.shields.io/badge/Github-SidraELEzz-orange?style=for-the-badge&logo=github)](https://github.com/SidraELEzz/)

[![Telegram](https://img.shields.io/badge/Telegram-SidraELEzz-orange?style=for-the-badge&logo=Telegram)](https://t.me/SidraTools)


